@@ -6,6 +6,9 @@ pub use tracer::Tracer;
 mod trace;
 pub use trace::Trace;
 
+// reexport the filter object
+pub use tracing_subscriber::EnvFilter;
+
 // export the trace listener utils
 mod utils;
 pub use utils::{create_trace_listener, TraceListenerOptions};
